@@ -41,6 +41,7 @@ struct field_operation_definition field_operations[] =
   {"max",     OP_MAX,     MODE_GROUPBY},
   {"absmin",  OP_ABSMIN,  MODE_GROUPBY},
   {"absmax",  OP_ABSMAX,  MODE_GROUPBY},
+  {"range",   OP_RANGE,   MODE_GROUPBY},
   {"first",   OP_FIRST,   MODE_GROUPBY},
   {"last",    OP_LAST,    MODE_GROUPBY},
   {"rand",    OP_RAND,    MODE_GROUPBY},
@@ -49,6 +50,7 @@ struct field_operation_definition field_operations[] =
   {"q1",      OP_QUARTILE_1, MODE_GROUPBY},
   {"q3",      OP_QUARTILE_3, MODE_GROUPBY},
   {"iqr",     OP_IQR,     MODE_GROUPBY},
+  {"perc",    OP_PERCENTILE, MODE_GROUPBY},
   {"pstdev",  OP_PSTDEV,  MODE_GROUPBY},
   {"sstdev",  OP_SSTDEV,  MODE_GROUPBY},
   {"pvar",    OP_PVARIANCE,    MODE_GROUPBY},
