@@ -31,6 +31,7 @@ enum field_operation
   OP_MAX,
   OP_ABSMIN,
   OP_ABSMAX,
+  OP_RANGE,
   OP_FIRST,
   OP_LAST,
   OP_RAND,
@@ -39,6 +40,7 @@ enum field_operation
   OP_QUARTILE_1,
   OP_QUARTILE_3,
   OP_IQR,       /* Inter-quartile range */
+  OP_PERCENTILE,
   OP_PSTDEV,    /* Population Standard Deviation */
   OP_SSTDEV,    /* Sample Standard Deviation */
   OP_PVARIANCE, /* Population Variance */
